@@ -1,6 +1,6 @@
 #
 # -*- Perl -*-
-# $Id: html.pl,v 1.32.4.2 2002/06/17 05:02:59 knok Exp $
+# $Id: html.pl,v 1.32 2001/01/13 09:16:04 kenji Exp $
 # Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
 # Copyright (C) 2000 Namazu Project All rights reserved.
 #     This is free software with ABSOLUTELY NO WARRANTY.
@@ -27,8 +27,6 @@ package html;
 use strict;
 require 'gfilter.pl';
 
-my $EMBEDDED_FILE = '\.(asp|jsp|php[3s]?|phtml)(?:\.gz)?';
-
 sub mediatype() {
     return ('text/html');
 }
@@ -65,10 +63,6 @@ sub filter ($$$$$) {
 	return $err if $err;
     }
 
-    if ($cfile =~ /($EMBEDDED_FILE)$/o) {
-       embedded_filter($cont);
-    }
-
     html_filter($cont, $weighted_str, $fields, $headings);
     
     gfilter::line_adjust_filter($cont);
@@ -105,7 +99,6 @@ sub html_filter ($$$$) {
     html::get_title_attr($contref);
     html::normalize_html_element($contref);
     html::erase_above_body($contref);
-    html::remove_comments($contref);
     html::weight_element($contref, $weighted_str, $headings);
     html::remove_html_elements($contref);
     # restore entities of each content.
@@ -117,18 +110,6 @@ sub html_filter ($$$$) {
     }
 }
 
-# Get rid of HTML-embedded codes
-sub embedded_filter ($) {
-    my ($contref) = @_;
-
-    # handle with ASP,JSP,PHP,VBScript,JScript and JavaScript.
-    $$contref =~ s/<%.*?%>//gs;
-    $$contref =~ s/<\?.*?\?>//gs;
-    $$contref =~ s/<asp:.*?\/>//gs;
-    $$contref =~ s/<jsp:.*?\/>//gs;
-    $$contref =~ s/<script.*>.*<\/script>//igs;
-}
-
 # Convert independent < > s into entity references for escaping.
 # Substitute twice for safe.
 sub escape_lt_gt ($) {
@@ -245,14 +226,6 @@ sub erase_above_body ($) {
 }
 
 
-# remove all comments. it's not perfect but almost works.
-sub remove_comments ($) {
-    my ($contref) = @_;
-
-    # remove all comments
-    $$contref =~ s/<!--.*?-->//gs;
-}
-
 # Weight a score of a keyword in a given text using %conf::Weight hash.
 # This process make the text be surround by temporary tags 
 # \x7fXX\x7f and \x7f/XX\x7f. XX represents score.
@@ -293,6 +266,9 @@ sub element_space ($) {
 sub remove_html_elements ($) {
     my ($contref) = @_;
 
+    # remove all comments
+    $$contref =~ s/<!--.*?-->//gs;
+
     # remove all elements
     $$contref =~ s!</?([A-Z]\w*)(?:\s+[A-Z]\w*(?:\s*=\s*(?:(["']).*?\2|[\w\-.]+))?)*\s*>!element_space($1)!gsixe;
 
