@@ -1,8 +1,8 @@
 #
 # -*- Perl -*-
-# $Id: msword.pl,v 1.28.4.11 2004/03/26 17:39:09 opengl2772 Exp $
+# $Id: msword.pl,v 1.28.4.1 2001/07/13 01:14:26 knok Exp $
 # Copyright (C) 1997-2000 Satoru Takabayashi All rights reserved.
-#               2000-2004 Namazu Project All rights reserved.
+# Copyright (C) 2000 Satoru Takabayashi Namazu Project All rights reserved.
 #     This is free software with ABSOLUTELY NO WARRANTY.
 #
 #  This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@
 
 package msword;
 use strict;
-use File::Basename;
+use File::Copy;
 require 'util.pl';
 require 'gfilter.pl';
 require 'html.pl';
@@ -33,7 +33,6 @@ require 'html.pl';
 my $wordconvpath  = undef;
 my $utfconvpath   = undef;
 my $wvversionpath = undef;
-my $wordconvname = undef;
 
 sub mediatype() {
     return ('application/msword');
@@ -80,11 +79,8 @@ sub filter ($$$$$) {
     my ($orig_cfile, $cont, $weighted_str, $headings, $fields)
       = @_;
     my $err = undef;
-
-    if (not defined $wordconvname) {
-	$wordconvname = basename($wordconvpath);
-    }
-    if ($wordconvname =~ /wvhtml/i) {
+ 
+    if (util::checkcmd('wvHtml')) {
     $err = filter_wv($orig_cfile, $cont, $weighted_str, $headings, $fields);
     } else { 
     $err = filter_doccat($orig_cfile, $cont, $weighted_str, $headings, $fields);
@@ -99,7 +95,7 @@ sub filter_wv ($$$$$) {
 
     my $tmpfile  = util::tmpnam('NMZ.word');
     my $tmpfile2 = util::tmpnam('NMZ.word2');
-    my ($ofile, $tpath, $options, $version) = ("", "", "", "");
+
 
     if (util::islang("ja")) {
     }
@@ -109,26 +105,16 @@ sub filter_wv ($$$$$) {
     { 
 	my $fh = util::efopen("> $tmpfile");
 	print $fh $$cont;
-        util::fclose($fh);
-    }
-
-    $version = `$wordconvpath --version 2>/dev/null`;
-    chomp $version;
-    if ($version ne "" and $version !~ /usage/i and $version ge "0.7") {
-       ($ofile, $tpath) = fileparse($tmpfile2);
-       $options = "--targetdir=$tpath";
-    } else {
-       $ofile = $tmpfile2;
     }
 
     if (!util::islang("ja")) {
-	system("$wordconvpath $options $tmpfile $ofile");
+	system("$wordconvpath $tmpfile $tmpfile2");
     } else {
 	my $version = "unknown";
 	my $supported = undef;
-	my $fh_cmd = util::efopen("$wvversionpath $tmpfile 2>/dev/null |");
+	my $fh_cmd = util::efopen("$wvversionpath $tmpfile |");
 	while (<$fh_cmd>) {
-	    if (/^Version: (word\d+)(?:,| )/i) {
+	    if (/^Version: (word\d+),/i) {
 		$version = $1;
 		#
 		# Only word8 format is supported for Japanese.
@@ -138,9 +124,8 @@ sub filter_wv ($$$$$) {
 		}
 	    }
 	}
-        util::fclose($fh_cmd);
 	return _("Unsupported format: ") .  $version unless $supported;
-	system("$wordconvpath $options $tmpfile $ofile 2>/dev/null");
+	system("$wordconvpath $tmpfile $tmpfile2");
         system("$utfconvpath -Iu8 -Oej $tmpfile2 > $tmpfile");
 	unlink($tmpfile2);
 	rename($tmpfile, $tmpfile2);
@@ -149,11 +134,9 @@ sub filter_wv ($$$$$) {
     {
 	my $fh = util::efopen("< $tmpfile2");
 	$$cont = util::readfile($fh);
-        util::fclose($fh);
-        codeconv::normalize_eucjp($cont);
 
 	# Exclude wvHtml's footer becaues it has no good index terms.
-        $$cont =~ s/(.*)<!--Section Ends-->.*$/$1/s;
+	$$cont =~ s/<!--Section Ends-->.*$//s;
     }
 
     unlink($tmpfile);
@@ -178,18 +161,13 @@ sub filter_doccat ($$$$$) {
  
     my $tmpfile  = util::tmpnam('NMZ.word');
     my $tmpfile2 = util::tmpnam('NMZ.word2');   
-    {
-        my $fh = util::efopen("> $tmpfile2");
-        print $fh $$cont;
-        util::fclose($fh);
-    }
+    copy("$cfile", "$tmpfile2");
 
     system("$wordconvpath -o e $tmpfile2 > $tmpfile");
 
     {
         my $fh = util::efopen("< $tmpfile");
         $$cont = util::readfile($fh);
-        util::fclose($fh);
     }
 
     unlink($tmpfile);
