@@ -1,10 +1,9 @@
 #
 # -*- Perl -*-
-# $Id: oleexcel.pl,v 1.11.4.13 2005/06/06 07:07:34 opengl2772 Exp $
+# $Id: oleexcel.pl,v 1.11.4.1 2001/11/29 11:46:48 takesako Exp $
 # Copyright (C) 2001 Yoshinori TAKESAKO,
-#               1999 Jun Kurabe,
-#               1999 Ken-ichi Hirose,
-#               2000-2005 Namazu Project All rights reserved.
+#               1999 Jun Kurabe ,
+#               1999 Ken-ichi Hirose All rights reserved.
 #     This is free software with ABSOLUTELY NO WARRANTY.
 #
 #  This program is free software; you can redistribute it and/or modify
@@ -49,25 +48,20 @@
 
 package oleexcel;
 use strict;
-use English;
 require 'util.pl';
 require 'gfilter.pl';
 
-use Win32;
 use Win32::OLE qw(in with);
-use Win32::OLE::Const;
+use Win32::OLE::Const 'Microsoft Excel';
 
 # for Excel application start only one time
-my $excel = undef;
-my $const = undef;
+my $excel;
 
-# Excel application destructor
+# Excel appliation destructor
 END {
-    if (defined $excel) {
-        util::vprint("Excel->Quit\n");
-        $excel->Quit();
-        undef $excel;
-    }
+    util::vprint("Excel->Quit\n");
+    $excel->Quit if defined $excel;
+    undef $excel;
 }
 
 sub mediatype() {
@@ -77,8 +71,8 @@ sub mediatype() {
 sub status() {
     open (SAVEERR,">&STDERR");
     open (STDERR,">nul");
-    $const = Win32::OLE::Const->Load("Microsoft Excel 11.0 Object Library");
-    $const = Win32::OLE::Const->Load("Microsoft Excel 10.0 Object Library") unless $const;
+    my $const;
+    $const = Win32::OLE::Const->Load("Microsoft Excel 10.0 Object Library");
     $const = Win32::OLE::Const->Load("Microsoft Excel 9.0 Object Library") unless $const;
     $const = Win32::OLE::Const->Load("Microsoft Excel 8.0 Object Library") unless $const;
     open (STDERR,">&SAVEERR");
@@ -95,7 +89,7 @@ sub pre_codeconv() {
 }
 
 sub post_codeconv () {
-    return 0;
+    return 1;
 }
 
 sub add_magic ($) {
@@ -104,8 +98,8 @@ sub add_magic ($) {
     return;
 }
 
-sub getProperties ($$$) {
-    my ($cfile, $fields, $weighted_str) = @_;
+sub getProperties ($$) {
+    my ($cfile, $fields) = @_;
 
     # See VBA online help using Microsoft Excel in detail.
     # Topic item: 'DocumentProperty Object'.
@@ -113,158 +107,70 @@ sub getProperties ($$$) {
     my $title = $cfile->BuiltInDocumentProperties('Title')->{Value};
     $title = $cfile->BuiltInDocumentProperties('Subject')->{Value}
 	unless (defined $title);
-    if (defined $title) {
-        $title = codeconv::shiftjis_to_eucjp($title);
-        codeconv::normalize_eucjp_document(\$title);
-        $fields->{'title'} = $title;
-
-        my $weight = $conf::Weight{'html'}->{'title'};
-        $$weighted_str .= "\x7f$weight\x7f$fields->{'title'}\x7f/$weight\x7f\n";
-    }
+    $fields->{'title'} = codeconv::shiftjis_to_eucjp($title)
+	if (defined $title);
 
     my $author = $cfile->BuiltInDocumentProperties('Last Author')->{Value};
     $author = $cfile->BuiltInDocumentProperties('Author')->{Value}
 	unless (defined $author);
-    if (defined $author) {
-        $author = codeconv::shiftjis_to_eucjp($author);
-        codeconv::normalize_eucjp_document(\$author);
-        $fields->{'author'} = $author;
-    }
+    $fields->{'author'} = codeconv::shiftjis_to_eucjp($author)
+	if (defined $author);
 
     # my $date = $cfile->BuiltInDocumentProperties('Last Save Time')->{Value};
     # $date = $cfile->BuiltInDocumentProperties('Creation Date')->{Value}
     #    unless (defined $date);
-    # if (defined $date) {
-    #     $date = codeconv::shiftjis_to_eucjp($date);
-    #     codeconv::normalize_eucjp_document(\$date);
-    #     $fields->{'date'} = $date;
-    # }
-
-    my $keyword = $cfile->BuiltInDocumentProperties('keywords')->{Value};
-    if (defined $keyword) {
-        $keyword = codeconv::shiftjis_to_eucjp($keyword);
-        codeconv::normalize_eucjp_document(\$keyword);
-
-        my $weight = $conf::Weight{'metakey'};
-        $$weighted_str .= "\x7f$weight\x7f$keyword\x7f/$weight\x7f\n";
-    }
+    # $fields->{'date'} = codeconv::shiftjis_to_eucjp($date)
+    #     if (defined $date);
 
     return undef;
 }
 
-sub Win32_FullPath ($) {
-    # c:/hoge/hoge.xls -> c:\hoge\hoge.xls
-    my $file = shift;
-    if ($English::Perl_VERSION >= 5.006) {
-	$file = Win32::GetFullPathName($file);
-    }
-    $file =~ s|/|\\|g;
-    return $file;
-}
-
-sub GetExt($) {
-    my ($filename) = @_;
-
-    my $ext = $filename;
-    $ext =~ s!.*/!!g;
-    if ($ext !~ s/^.*(\.[^\.]*)$/$1/) {
-        $ext = "";
-    }
-
-    return $ext;
-}
-
-my $Count = 0;
-
 sub filter ($$$$$) {
     my ($orig_cfile, $cont, $weighted_str, $headings, $fields) = @_;
     my $cfile = defined $orig_cfile ? $$orig_cfile : '';
+    my $fileName = $cfile;
 
     util::vprint("Processing excel file ...\n");
 
-    my $err = ReadDocument($cfile, $cont, $weighted_str, $headings, $fields);
-    return $err if (defined $err);
-
-    gfilter::line_adjust_filter($cont);
-    gfilter::line_adjust_filter($weighted_str);
-    gfilter::white_space_adjust_filter($cont);
-    $fields->{'title'} = gfilter::filename_to_title($cfile, $weighted_str)
-	unless $fields->{'title'};
-    gfilter::show_filter_debug_info($cont, $weighted_str, $fields, $headings);
-
-    return undef;
-}
-
-sub ReadDocument ($$$$$) {
-    my ($cfile, $cont, $weighted_str, $headings, $fields) = @_;
-
-    my $ext = GetExt($cfile);
-    my $tmpfile = util::tmpnam('NMZ.oleexcel') . $ext;
-    {
-        my $fh = util::efopen("> $tmpfile");
-        print $fh $$cont;
-        util::fclose($fh);
-    }
-
-    my $err = ReadExcel($tmpfile, $cont, $weighted_str, $headings, $fields);
-    unlink($tmpfile);
-
-    # codeconv::toeuc($cont);
-    codeconv::codeconv_document($cont);
-
-    # TEXT_SIZE_MAX
-    my $text_size_max = $conf::TEXT_SIZE_MAX;
-    if (length($$cont) > $text_size_max) {
-	util::vprint("text size is too LARGE! Cut down on test size: $text_size_max bytes");
-	$$cont = substr($$cont, 0, $text_size_max);
-	$$cont =~ s/\n.*$//m;
-    }
-
-    return $err;
-}
-
-sub ReadExcel ($$$$$) {
-    my ($cfile, $cont, $weighted_str, $headings, $fields) = @_;
-
-    my $win32filename = $cfile;
-    $win32filename =~ s/\//\\/g;
-    $$cont = "";
-
     # make temporary file name
-    my $tmpfile0 = util::tmpnam("NMZ.xls.$Count.0");
-    my $tmpfile1 = util::tmpnam("NMZ.xls.$Count.1");
-    my $tmpfile2 = util::tmpnam("NMZ.xls.$Count.2");
-    $Count++;
+    my $tmpfile0 = util::tmpnam('NMZ.xls0');
+    my $tmpfile1 = util::tmpnam('NMZ.xls1');
+    my $tmpfile2 = util::tmpnam('NMZ.xls2');
+
+    # c:/hoge/hoge.xls -> c:\hoge\hoge.xls
+    $fileName =~ s|/|\\|g;
+    $tmpfile0 =~ s|/|\\|g;
+    $tmpfile1 =~ s|/|\\|g;
+    $tmpfile2 =~ s|/|\\|g;
 
     # use existing instance if Excel is already running.
     # my $excel;
-    # eval {$excel = Win32::OLE->GetActiveObject('Excel.Application')};
-    # die "MSExcel not installed" if $@;
+    eval {$excel = Win32::OLE->GetActiveObject('Excel.Application')};
+    die "MSExcel not installed" if $@;
     unless (defined $excel) {
 	$excel = Win32::OLE->new('Excel.Application', sub {$_[0]->Quit;})
-	    or return "Oops, cannot start Excel." . Win32::OLE->LastError();
+	    or die "Oops, cannot start Excel";
     }
 
-    $Win32::OLE::Warn = 0;             # False
-    $excel->{Visible} = 0;             # False
-    $excel->{DisplayAlerts} = 0;       # False
-    $excel->{EnableEvents} = 0;        # False
-    $excel->{AutomationSecurity} = 3;  # msoAutomationSecurityForceDisable
+    $Win32::OLE::Warn = 0;
+    $excel->{Visible} = 0;
+    $excel->{DisplayAlerts} = 0;
+    $excel->{EnableEvents} = 0;
 
     # Open the excel workbooks.
     # In order to skip password-protected file, send a dummy password.
     my $Book = $excel->Workbooks->Open({
-	'FileName'                  => $win32filename,
-	'Updatelinks'               => 0,  # False
-	'ReadOnly'                  => 1,  # True
-	'Password'                  => 'dummy password',
-	'WriteResPassword'          => 'dummy password',
-	'IgnoreReadOnlyRecommended' => 1   # True
+	'FileName'			=> $fileName,
+	'ReadOnly'			=> 1,
+	'IgnoreReadOnlyRecommended'	=> 1,
+	'Updatelinks'			=> 0,
+	'WriteResPassword'		=> 'dummy password',
+	'Password'			=> 'dummy password'
     });
-    return "Cannot open File $cfile" unless (defined $Book);
+    return "$fileName: cannot open file\n" unless (defined $Book);
 
     # get some properties
-    getProperties($Book, $fields, $weighted_str);
+    getProperties($Book, $fields);
 
     # FileHandle for temporary file 1,2
     local (*FH1, *FH2);
@@ -279,11 +185,10 @@ sub ReadExcel ($$$$$) {
 	my $sheetName = $sheet->Name;
 
 	# SaveAs xlText FileFormat
-	$sheet->Select;
-	my $ret = $excel->ActiveWorkbook->SaveAs({
-	    'FileName'     => &Win32_FullPath($tmpfile),
-	    'FileFormat'   => $const->{xlText},  # xlText
-	    'CreateBackup' => 0                  # False
+	my $ret = $sheet->SaveAs({
+	    FileName		=>	$tmpfile,	# 
+	    FileFormat		=>	xlText,		# 
+	    CreateBackup	=>	0		# False
 	});
 
 	# print this sheetName
@@ -320,23 +225,34 @@ sub ReadExcel ($$$$$) {
 	close(FH2);
     }
 
-    $Book->Close({
-        'SaveChanges' => 0  # False
-    });
+    $Book->Close(0);
     undef $Book;
     # undef $excel;
 
     # read all text from temporary file 2
-    {
-        my $fh2 = util::efopen("< $tmpfile2");
-        $$cont = util::readfile($fh2);
-        util::fclose($fh2);
-        undef $fh2;
-    }
+    my $fh2 = util::efopen("< $tmpfile2");
+    $$cont = util::readfile($fh2);
+    undef $fh2;
 
     # unlink temporary file 0,1,2
     unlink $tmpfile0, $tmpfile1, $tmpfile2;
 
+    # TEXT_SIZE_MAX
+    my $text_size_max = 1000000;
+    $text_size_max = $conf::TEXT_SIZE_MAX if defined $conf::TEXT_SIZE_MAX;
+    if (length($$cont) > $text_size_max) {
+	util::vprint("text size is too LARGE! Cut down on test size: $text_size_max bytes");
+	$$cont = substr($$cont, 0, $text_size_max);
+	$$cont =~ s/\n.*$//m;
+    }
+
+    # gfilter::line_adjust_filter($cont);
+    gfilter::line_adjust_filter($weighted_str);
+    # gfilter::white_space_adjust_filter($cont);
+    $fields->{'title'} = gfilter::filename_to_title($cfile, $weighted_str)
+	unless $fields->{'title'};
+    gfilter::show_filter_debug_info($cont, $weighted_str, $fields, $headings);
+
     return undef;
 }
 
