@@ -1,11 +1,10 @@
 # 
 # -*- Perl -*-
-# $Id: olertf.pl,v 1.4.4.6 2004/10/30 18:46:12 opengl2772 Exp $
+# $Id: olertf.pl,v 1.4.4.1 2001/11/29 11:46:48 takesako Exp $
 # 
-# Copyright (C) 2000 Yoshinori.TAKESAKO,
-#               2000 Jun Kurabe,
-#               2000 Ken-ichi Hirose,
-#               2004 Namazu Project All rights reserved.
+# Copyright (C) 2000 Yoshinori.TAKESAKO ,
+#               2000 Jun Kurabe ,
+#               2000 Ken-ichi Hirose All rights reserved.
 #     This is free software with ABSOLUTELY NO WARRANTY.
 #
 #  This program is free software; you can redistribute it and/or modify
@@ -30,23 +29,16 @@ package olertf;
 use strict;
 require 'util.pl';
 require 'gfilter.pl';
-require 'olemsword.pl';
-
-use Win32::OLE::Const;
 
 sub mediatype() {
     return ('application/rtf');
 }
 
 sub status() {
-    # The check of a dependence filter.
-    return 'no' if (olemsword::status() ne 'yes');
-
     open (SAVEERR,">&STDERR");
     open (STDERR,">nul");
     my $const;
-    $const = Win32::OLE::Const->Load("Microsoft Word 11.0 Object Library");
-    $const = Win32::OLE::Const->Load("Microsoft Word 10.0 Object Library") unless $const;
+    $const = Win32::OLE::Const->Load("Microsoft Word 10.0 Object Library");
     $const = Win32::OLE::Const->Load("Microsoft Word 9.0 Object Library") unless $const;
     $const = Win32::OLE::Const->Load("Microsoft Word 8.0 Object Library") unless $const;
     open (STDERR,">&SAVEERR");
@@ -63,7 +55,7 @@ sub pre_codeconv() {
 }
 
 sub post_codeconv () {
-    return 0;
+    return 1;
 }
 
 sub add_magic ($) {
@@ -79,8 +71,10 @@ sub filter ($$$$$) {
 
     util::vprint("Processing rtf file ...\n");
 
-    my $err = ReadMSWord::ReadDocument($cfile, $cont, $fields, $weighted_str);
-    return $err if (defined $err);
+    $cfile =~ s/\//\\/g;
+    $$cont = "";
+    ReadMSWord::ReadMSWord($cfile, $cont, $fields);
+    $cfile = defined $orig_cfile ? $$orig_cfile : '';
 
     gfilter::line_adjust_filter($cont);
     gfilter::line_adjust_filter($weighted_str);
