@@ -1,9 +1,9 @@
 /*
  * 
- * $Id: field.c,v 1.29.8.10 2006/04/15 17:44:18 opengl2772 Exp $
+ * $Id: field.c,v 1.29.8.3 2001/12/21 05:36:40 knok Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000-2006 Namazu Project All rights reserved.
+ * Copyright (C) 2000,2001 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -48,13 +48,6 @@
 #include "replace.h"
 #include "idxname.h"
 
-/*
- * Private variables
- */
-
-static int cache_idx = 0, cache_num = 0;
-static struct field_cache fc[FIELD_CACHE_SIZE];
-
 /*
  *
  * Private functions
@@ -65,7 +58,6 @@ static void apply_field_alias ( char *field );
 static int is_field_safe_char ( int c );
 static void make_fullpathname_field ( int n );
 
-
 static void 
 apply_field_alias(char *field)
 {
@@ -122,7 +114,7 @@ nmz_isfield(const char *key)
         }
         key++;
     }
-    if (nmz_isalpha((unsigned char)*(key - 1)) && *key == ':' ) {
+    if (isalpha(*(key - 1)) && *key == ':' ) {
         return 1;
     }
     return 0;
@@ -159,10 +151,18 @@ nmz_get_field_name(const char *fieldpat)
 void 
 nmz_get_field_data(int idxid, int docid, const char *field, char *data) 
 {
-    char fname[BUFSIZE] = "";
-    char tmpfield[BUFSIZE] = "";
+    char fname[BUFSIZE];
+    char tmpfield[BUFSIZE];
     int i;
+    static int cache_idx = 0, cache_num = 0;
     FILE *fp_field, *fp_field_idx;
+    struct field_cache {
+	int idxid;
+	int docid;
+	char field[BUFSIZE];
+	char data[BUFSIZE];
+    };
+    static struct field_cache fc[FIELD_CACHE_SIZE];
 
     strcpy(data, ""); /* For safety. */
 
@@ -199,7 +199,6 @@ nmz_get_field_data(int idxid, int docid, const char *field, char *data)
     fp_field_idx = fopen(fname, "rb");
     if (fp_field_idx == NULL) {
         nmz_warn_printf("%s: %s", fname, strerror(errno));
-        fclose(fp_field);
 	return;
     }
 
@@ -219,24 +218,11 @@ nmz_get_field_data(int idxid, int docid, const char *field, char *data)
     fc[cache_idx].idxid = idxid;
     fc[cache_idx].docid = docid;
     strncpy(fc[cache_idx].field, tmpfield, BUFSIZE - 1);
-    fc[cache_idx].field[BUFSIZE - 1] = '\0';
     strncpy(fc[cache_idx].data, data, BUFSIZE - 1);
-    fc[cache_idx].data[BUFSIZE - 1] = '\0';
     cache_idx = (cache_idx + 1) % FIELD_CACHE_SIZE;
     if (cache_num < FIELD_CACHE_SIZE) {
 	cache_num++;
     }
 }
 
-void
-nmz_free_field_cache(void)
-{
-       int i;
-       for(i = 0; i < cache_num; i++) {
-               fc[i].idxid =0;
-               fc[i].docid =0;
-               strcpy(fc[i].field, "");
-               strcpy(fc[i].data, "");
-       }
-       cache_num = 0;
-}
+
