@@ -1,9 +1,9 @@
 /*
  * i18n.c -
- * $Id: i18n.c,v 1.26.4.12 2008/03/06 15:38:09 opengl2772 Exp $
+ * $Id: i18n.c,v 1.26.4.4 2001/12/21 05:36:40 knok Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000-2008 Namazu Project All rights reserved.
+ * Copyright (C) 2000,2001 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -23,27 +23,20 @@
  * 
  * 
  */
-
+#include <stdio.h>
+#include <stdlib.h>
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
-#ifdef HAVE_SUPPORT_H
-#  include "support.h"
-#endif
-
-#include <stdio.h>
-#ifdef HAVE_STDLIB_H
-#  include <stdlib.h>
-#endif
 
 #ifdef HAVE_STRING_H
-#  include <string.h>
+#include <string.h>
 #else
-#  include <strings.h>
+#include <strings.h>
 #endif
 
 #ifdef HAVE_LOCALE_H
-#  include <locale.h>
+# include <locale.h>
 #endif
 
 #include "libnamazu.h"
@@ -58,7 +51,6 @@
 
 static const char *guess_category_value ( const char *categoryname );
 static char *get_lang_by_category ( const char *categoryname );
-static int _purification_lang( char *lang, size_t n );
 
 
 /* The following is (partly) taken from the gettext package.
@@ -103,21 +95,12 @@ guess_category_value (const char *categoryname)
 static char *
 get_lang_by_category(const char *categoryname) 
 {
-    static char lang[BUFSIZE] = "";
-    char *value;
-
-    value = (char *)guess_category_value(categoryname);
-    if (value == NULL) {
-        return "C";
-    } else {
-        strncpy(lang, value, BUFSIZE - 1);
-        lang[BUFSIZE - 1] = '\0';
-        _purification_lang(lang, BUFSIZE);
-        if (lang[0] == '\0') {
-            return "C";
-        }
-        return lang;
-    }
+    char *lang;
+    lang = (char *)guess_category_value(categoryname);
+    if (lang == NULL)
+	return "C";
+    else
+	return lang;
 }
 
 /*
@@ -127,14 +110,10 @@ get_lang_by_category(const char *categoryname)
  */
 
 char *
-nmz_set_lang(const char *value)
+nmz_set_lang(const char *lang)
 {
-    static char lang[BUFSIZE] = "";
     const char* env;
 
-    strncpy(lang, value, BUFSIZE - 1);
-    _purification_lang(lang, BUFSIZE);
-
     env = guess_category_value("LC_MESSAGES");
     if (env == NULL && *lang != '\0') {
 #ifdef HAVE_SETENV
@@ -142,10 +121,8 @@ nmz_set_lang(const char *value)
 #else
 # ifdef HAVE_PUTENV
 	{
-	    static char *store = NULL;
+	    static char *store;
 
-	    if (store != NULL)
-		free(store);
 	    store = (char *)malloc(strlen(lang) + 6); /* do *not* free */
 	    if (store == NULL)
 		return NULL; /* FIXME: should be fatal error */
@@ -185,15 +162,13 @@ enum nmz_stat
 nmz_choose_msgfile_suffix(const char *pfname,  char *lang_suffix)
 {
     FILE *fp;
-    size_t baselen;
-    char fname[BUFSIZE] = "";
-    char suffix[BUFSIZE] = "";
+    int baselen;
+    char fname[BUFSIZE];
 
     strncpy(fname, pfname, BUFSIZE - 1);
     baselen = strlen(fname);
     strncat(fname, ".", BUFSIZE - strlen(fname) - 1);
-    nmz_delete_since_path_delimitation(suffix, nmz_get_lang(), BUFSIZE);
-    strncat(fname, suffix, BUFSIZE - strlen(fname) - 1);
+    strncat(fname, nmz_get_lang(), BUFSIZE - strlen(fname) - 1);
 
     /* 
      * Trial example:
@@ -215,7 +190,7 @@ nmz_choose_msgfile_suffix(const char *pfname,  char *lang_suffix)
 	}
 	nmz_debug_printf("choose_msgfile: %s open failed.\n", fname);
 
-	for (i = (int)strlen(fname) - 1; i >= 0; i--) {
+	for (i = strlen(fname) - 1;  i >= 0; i--) {
 	    if (fname[i] == '.' ||
 		fname[i] == '_')
 	    {
@@ -230,35 +205,4 @@ nmz_choose_msgfile_suffix(const char *pfname,  char *lang_suffix)
     return FAILURE;
 }
 
-/*
- *   purification language.
- *     [A-Za-z][A-Za-z0-9_,+@\-\.=]*
- *     (ex. ja_JP.eucJP, ja_JP.SJIS, C)
- */
-static int _purification_lang(char *lang, size_t n)
-{
-    char *p;
 
-    p = lang;
-
-    /*   [A-Za-z][A-Za-z0-9_,+@\-\.=]*   */
-    if ((*p >= 'A' && *p <= 'Z') || (*p >= 'a' && *p <= 'z')) {
-        p++;
-        while(*p) {
-            if ((*p >= 'A' && *p <= 'Z') || (*p >= 'a' && *p <= 'z')
-            || (*p >= '0' && *p <= '9')
-            || *p == '_' || *p == ',' || *p == '+' || *p == '@' 
-            || *p == '-' || *p == '.' || *p == '='
-            ) {
-            } else {
-                *p = '\0';
-                break;
-            }
-            p++;
-        }
-    } else {
-        *p = '\0';
-    }
-
-    return 1;
-}
