@@ -2,10 +2,10 @@
  * 
  * replace.c - 
  *
- * $Id: replace.c,v 1.15.8.8 2008-03-06 15:38:09 opengl2772 Exp $
+ * $Id: replace.c,v 1.15.8.3 2001/12/21 05:36:40 knok Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000-2008 Namazu Project All rights reserved.
+ * Copyright (C) 2000,2001 Namazu Project All rights reserved.
  * Copyright (C) 1999 NOKUBI Takatsugu All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
@@ -33,21 +33,15 @@
 #ifdef HAVE_SUPPORT_H
 #  include "support.h"
 #endif
-
 #include <stdio.h>
-#ifdef HAVE_STDLIB_H
-#  include <stdlib.h>
-#endif
+#include <stdlib.h>
 #include <assert.h>
-
-#ifdef HAVE_ERRNO_H
-#  include <errno.h>
-#endif
+#include <errno.h>
 
 #ifdef HAVE_STRING_H
-#  include <string.h>
+#include <string.h>
 #else
-#  include <strings.h>
+#include <strings.h>
 #endif
 
 #include "replace.h"
@@ -90,7 +84,7 @@ int
 nmz_replace_uri(char *uri)
 {
     int npat, nrep, i, j;
-    char tmp[BUFSIZE] = "";
+    char tmp[BUFSIZE];
     struct nmz_replace *list = replaces;
     int is_regex_matching = 0;
 
@@ -171,8 +165,8 @@ nmz_replace_uri(char *uri)
 	}
 	/* Otherwise, we fall back to string substitution */
 
-	npat = (int)strlen(list->pat);
-	nrep = (int)strlen(list->rep);
+	npat = strlen(list->pat);
+	nrep = strlen(list->rep);
 
 	if (strncmp(list->pat, tmp, npat) == 0) {
 	    strcpy(uri, list->rep);
@@ -204,15 +198,12 @@ nmz_add_replace(const char *pat, const char *rep)
     newp->pat = malloc(strlen(pat) + 1);
     if (newp->pat == NULL) {
 	 nmz_set_dyingmsg(nmz_msg("%s", strerror(errno)));
-         free(newp);
 	 return FAILURE;
     }
 
     newp->rep = malloc(strlen(rep) + 1);
     if (newp->rep == NULL) {
 	 nmz_set_dyingmsg(nmz_msg("%s", strerror(errno)));
-         free(newp->pat);
-         free(newp);
 	 return FAILURE;
     }
 
