@@ -2,10 +2,10 @@
  * 
  * score.c - scoring-related functions of Namazu
  * 
- * $Id: score.c,v 1.3.4.12 2008/03/06 15:38:09 opengl2772 Exp $
+ * $Id: score.c,v 1.3.4.4 2001/12/21 05:36:40 knok Exp $
  * 
  * Copyright (C) 2001 Hajime BABA  All rights reserved.
- * Copyright (C) 2001-2008 Namazu Project All rights reserved.
+ * Copyright (C) 2001 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -29,6 +29,11 @@
 
 /* #define SCORE_C_DEBUG    / * for internal use only */
 
+#include <stdio.h>
+#include <stdlib.h>
+#include <math.h>
+#include <errno.h>
+#include <time.h>
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
@@ -36,17 +41,6 @@
 #  include "support.h"
 #endif
 
-#include <stdio.h>
-#ifdef HAVE_STDLIB_H
-#  include <stdlib.h>
-#endif
-#include <math.h>
-#include <time.h>
-
-#ifdef HAVE_ERRNO_H
-#  include <errno.h>
-#endif
-
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #else
@@ -56,9 +50,9 @@
 #endif
 
 #ifdef HAVE_STRING_H
-#  include <string.h>
+#include <string.h>
 #else
-#  include <strings.h>
+#include <strings.h>
 #endif
 
 #include "libnamazu.h"
@@ -115,7 +109,7 @@ static int
 get_field_size(int docid, int idxid)
 {
     FILE *fp_field, *fp_field_idx;
-    char fname[BUFSIZE] = "", buf[BUFSIZE];
+    char fname[BUFSIZE], buf[BUFSIZE];
     int size;
     
     /* Make a pathname */
@@ -132,7 +126,6 @@ get_field_size(int docid, int idxid)
     fp_field_idx = fopen(fname, "rb");
     if (fp_field_idx == NULL) {
         nmz_warn_printf("%s: %s", fname, strerror(errno));
-        fclose(fp_field_idx);
 	return 0;
     }
 
@@ -153,7 +146,7 @@ static int
 get_field_time(int docid, int idxid)
 {
     FILE *fp_field;
-    char fname[BUFSIZE] = "";
+    char fname[BUFSIZE];
     unsigned int t;
     
     /* Make a pathname */
@@ -180,7 +173,7 @@ static void
 get_field_uri(char *uri, int docid, int idxid)
 {
     FILE *fp_field, *fp_field_idx;
-    char fname[BUFSIZE] = "", buf[BUFSIZE];
+    char fname[BUFSIZE], buf[BUFSIZE];
     
     /* Make a pathname */
     make_fullpathname_field(idxid);
@@ -196,7 +189,6 @@ get_field_uri(char *uri, int docid, int idxid)
     fp_field_idx = fopen(fname, "rb");
     if (fp_field_idx == NULL) {
         nmz_warn_printf("%s: %s", fname, strerror(errno));
-        fclose(fp_field_idx);
 	return;
     }
 
@@ -314,11 +306,11 @@ get_freshness_factor(int date)
  *
  * factor  URI
  * ==================================
- * 2.0     http://www.example.jp/
- * 1.7     http://www.example.jp/a/
- * 1.5     http://www.example.jp/a/b/
- * 1.2     http://www.example.jp/a/b/c/
- * 1.0     http://www.example.jp/a/b/c/d/
+ * 2.0     http://www.foo.jp/
+ * 1.7     http://www.foo.jp/a/
+ * 1.5     http://www.foo.jp/a/b/
+ * 1.2     http://www.foo.jp/a/b/c/
+ * 1.0     http://www.foo.jp/a/b/c/d/
  *
  * NOTE: This factor function is derived empirically.
  *
@@ -437,22 +429,19 @@ nmz_recompute_score(NmzResult *hlist)
     double qds_dis_ratio = 1.0;
     int i;
     
-    orig = malloc(sizeof(int) * hlist->num);
+    orig = malloc(sizeof(int)*(hlist->num + 1));
     if (orig == NULL) {
 	 nmz_set_dyingmsg(nmz_msg("%s", strerror(errno)));
 	 return;
     }
-    qds =  malloc(sizeof(double) * hlist->num);
+    qds =  malloc(sizeof(double)*(hlist->num + 1));
     if (qds == NULL) {
 	 nmz_set_dyingmsg(nmz_msg("%s", strerror(errno)));
-         free(orig);
 	 return;
     }
-    dis =  malloc(sizeof(double) * hlist->num);
+    dis =  malloc(sizeof(double)*(hlist->num + 1));
     if (dis == NULL) {
 	 nmz_set_dyingmsg(nmz_msg("%s", strerror(errno)));
-         free(orig);
-         free(qds);
 	 return;
     }
     
