@@ -15,6 +15,14 @@
 #define memset _nmz_memset
 #endif
 
+#ifndef HAVE_STRCASECMP
+#define strcasecmp _nmz_strcasecmp
+#endif
+
+#ifndef HAVE_STRNCASECMP
+#define strncasecmp _nmz_strncasecmp
+#endif
+
 #ifndef HAVE_STRCSPN
 #define strcspn _nmz_strcspn
 #endif
@@ -23,22 +31,16 @@
 #define strerror _nmz_strerror
 #endif
 
-#if defined (_WIN32) && !defined (__CYGWIN__)
-#define strcasecmp stricmp
-#define strncasecmp strnicmp
-#define snprintf _snprintf
-#define vsnprintf _vsnprintf
-#else
-# ifndef HAVE_STRCASECMP
-# define strcasecmp _nmz_strcasecmp
+#ifndef HAVE_VSNPRINTF
+# ifdef HAVE__VSNPRINTF
+# define vsnprintf _vsnprintf
+# else
+#  ifdef HAVE___VSNPRINTF
+#  define vsnprintf __vsnprintf
+#  else
+#  define vsnprintf _nmz_vsnprintf
+#  endif
 # endif
-# ifndef HAVE_STRNCASECMP
-# define strncasecmp _nmz_strncasecmp
-# endif
-# ifndef HAVE_VSNPRINTF
-# define snprintf _nmz_snprintf
-# define vsnprintf _nmz_vsnprintf
-# endif 
 #endif
 
 #endif /* _SUPPORT_H */
