@@ -1,9 +1,9 @@
 /*
  * 
- * $Id: util.c,v 1.75.4.14 2004/03/20 15:25:10 usu Exp $
+ * $Id: util.c,v 1.75.4.4 2001/12/21 05:36:41 knok Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000-2004 Namazu Project All rights reserved.
+ * Copyright (C) 2000,2001 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -102,9 +102,9 @@ decode_uri_sub(char c1, char c2)
  */
 
 unsigned long
-nmz_scan_oct(const char *start, int len, int *retlen)
+nmz_scan_oct(char *start, int len, int *retlen)
 {
-    register const char *s = start;
+    register char *s = start;
     register unsigned long retval = 0;
 
     while (len-- && *s >= '0' && *s <= '7') {
@@ -117,10 +117,10 @@ nmz_scan_oct(const char *start, int len, int *retlen)
 }
 
 unsigned long
-nmz_scan_hex(const char *start, int len, int *retlen)
+nmz_scan_hex(char *start, int len, int *retlen)
 {
     static char hexdigit[] = "0123456789abcdef0123456789ABCDEFx";
-    register const char *s = start;
+    register char *s = start;
     register unsigned long retval = 0;
     char *tmp;
 
@@ -267,36 +267,20 @@ void
 nmz_warn_printf(const char *fmt, ...)
 {
     va_list args;
-    FILE *fp;
 
-    if (!nmz_is_loggingmode())
-	return;
-    if (nmz_is_output_warn_to_file()) {
-	fp = fopen(NMZ.warnlog, "a+");
-	if (fp == NULL) {
-	    fprintf(stderr, "Can't open NMZ.warnlog.\n");
-	    return;
-	}
-    } else {
-	fp = stderr;
-    }
+    fflush(stdout);
 
-    fflush(fp);
-
-    fprintf(fp, "%s: ", PACKAGE);
+    fprintf(stderr, "%s: ", PACKAGE);
 
     va_start(args, fmt);
-    vfprintf(fp, fmt, args);
+    vfprintf(stderr, fmt, args);
     va_end(args);
 
     if (fmt[strlen(fmt) - 1] != '\n') {
-	fprintf(fp, "\n");
+	fprintf(stderr, "\n");
     }
 
-    fflush(fp);
-
-    if (fp != stderr)
-	fclose(fp);
+    fflush(stderr);
 }
 
 /* 
@@ -343,7 +327,6 @@ nmz_pathcat(const char *base, char *name)
         }
     }
     strncpy(work, base, BUFSIZE - 1);
-    work[BUFSIZE - 1] = '\0';
     strncat(work, "/", BUFSIZE - strlen(work) - 1);
     strncat(work, name, BUFSIZE - strlen(work) - 1);
     strncpy(name, work, BUFSIZE - 1);
@@ -457,15 +440,12 @@ nmz_readfile(const char *fname)
     buf = malloc(fstatus.st_size + 1);
     if (buf == NULL) {
 	nmz_set_dyingmsg(nmz_msg("%s: %s", fname, strerror(errno)));
-        fclose(fp);
 	return NULL;
     }
     if (fstatus.st_size != 0 &&
 	fread(buf, sizeof(char), fstatus.st_size, fp) == 0) 
     {
         nmz_set_dyingmsg(nmz_msg("%s: %s", fname, strerror(errno)));
-        free(buf);
-        fclose(fp);
 	return NULL;
     }
     *(buf + fstatus.st_size) = '\0';
@@ -492,10 +472,8 @@ nmz_decode_uri(char *str)
     int i, j;
     for (i = j = 0; str[i]; i++, j++) {
 	if (str[i] == '%') {
-	    if (str[i+1] != 0 && str[i+2] != 0) {
-		str[j] = decode_uri_sub(str[i + 1], str[i + 2]);
-		i += 2;
-	    }
+	    str[j] = decode_uri_sub(str[i + 1], str[i + 2]);
+	    i += 2;
 	} else if (str[i] == '+') {
 	    str[j] = ' ';
 	} else {
@@ -555,7 +533,7 @@ nmz_strerror(enum nmz_stat errnum)
 	msg = _("The index is locked for maintenance");
 	break;
     case ERR_OLD_INDEX_FORMAT:
-	msg = _("Present index is old type. it's unsupported.");
+	msg = _("The index should be old format.");
 	break;
     default:
 	msg = _("Unknown error. Report bug!");
