@@ -1,14 +1,14 @@
 # -*- Perl -*-
-# $Id: var.pl.in,v 1.12.8.4 2009-01-29 02:29:00 opengl2772 Exp $
+# $Id: var.pl.in,v 1.12 2000/03/02 02:39:33 satoru Exp $
 # Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
-# Copyright (C) 2000-2009 Namazu Project All rights reserved.
+# Copyright (C) 2000 Namazu Project All rights reserved.
 #     This is free software with ABSOLUTELY NO WARRANTY.
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
 #  the Free Software Foundation; either versions 2, or (at your option)
 #  any later version.
-#
+# 
 #  This program is distributed in the hope that it will be useful
 #  but WITHOUT ANY WARRANTY; without even the implied warranty of
 #  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -29,10 +29,9 @@ package var;
 # Software information.
 #
 
-$VERSION         = "2.0.19";
-$COPYRIGHT       = "Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.\nCopyright (C) 2000-2009 Namazu Project All rights reserved."; # should be doublequote
+$VERSION         = "2.0.10";
+$COPYRIGHT       = "Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.\nCopyright (C) 2000,2001 Namazu Project All rights reserved."; # should be doublequote
 $MAILING_ADDRESS = 'bug-namazu@namazu.org';
-$TRAC_URI        = 'http://www.namazu.org/trac-namazu/trac.cgi';
 
 #-----------------------------------------------------------
 #
@@ -107,10 +106,6 @@ $Opt{'noencodeuri'}   = 0;
 $Opt{'nodelete'} = 0;
 $Opt{'noupdate'} = 0;
 
-$Opt{'checkfilesize'} = 0;
-
-$Opt{'decodebase64'} = 0;
-
 #-----------------------------------------------------------
 #
 # Size of `int'
@@ -134,15 +129,15 @@ $USE_NKF_MODULE = 0;
 
 %REQUIRE_ACTIONS = ();
 %RECURSIVE_ACTIONS = ();
-%REQUIRE_PRE_CODECONV =
+%REQUIRE_PRE_CODECONV = 
     (
      'text/plain' => 1,
      );
-%REQUIRE_POST_CODECONV =
+%REQUIRE_POST_CODECONV = 
     (
      'text/plain' => 0,
      );
-%Supported =
+%Supported = 
     (
      'text/plain' => "yes",
      );
