@@ -2,10 +2,10 @@
  * 
  * cgi.c -
  * 
- * $Id: cgi.c,v 1.61.4.22 2007/12/05 16:59:35 opengl2772 Exp $
+ * $Id: cgi.c,v 1.61.4.8 2001/12/21 08:44:40 knok Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000-2007 Namazu Project All rights reserved.
+ * Copyright (C) 2000 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -25,15 +25,13 @@
  * 
  * 
  */
-
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
 #include <assert.h>
+#ifdef HAVE_CONFIG_H
+#  include "config.h"
+#endif
 
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
@@ -44,9 +42,9 @@
 #endif
 
 #ifdef HAVE_STRING_H
-#  include <string.h>
+#include <string.h>
 #else
-#  include <strings.h>
+#include <strings.h>
 #endif
 
 #include "namazu.h"
@@ -123,29 +121,22 @@ validate_idxname(const char * idxname)
 #endif
 
     if (*idxname == '\0' || *idxname == '/' || (win32 && *idxname == '\\')) {
-        printf("%s %s; %s" CRLF CRLF, MSG_MIME_HEADER,
-            "text/html", _("charset=ISO-8859-1"));
-        printf("<html><body>\n");
+        printf("%s text/html" CRLF CRLF, MSG_MIME_HEADER);
 	puts_entitize(idxname);
 	printf(" : ");
         printf(_("Invalid idxname."));
-        printf("\n</body></html>\n");
-        exit_nmz(EXIT_FAILURE);
+        exit(EXIT_FAILURE);
     }
     while (*idxname) {
         if (nmz_strprefixcasecmp("../", idxname) == 0 ||
 	    strcmp("..", idxname) == 0 ||
-            (win32 && nmz_strprefixcasecmp("..\\", idxname) == 0) || 
-            (win32 && nmz_strprefixcasecmp("..." , idxname) == 0)) 
+            (win32 && nmz_strprefixcasecmp("..\\", idxname) == 0)) 
         {
-            printf("%s %s; %s" CRLF CRLF, MSG_MIME_HEADER,
-                "text/html", _("charset=ISO-8859-1"));
-            printf("<html><body>\n");
+	    printf("%s text/html" CRLF CRLF, MSG_MIME_HEADER);
 	    puts_entitize(idxname);
 	    printf(" : ");
             printf(_("Invalid idxname."));
-            printf("\n</body></html>\n");
-            exit_nmz(EXIT_FAILURE);
+            exit(EXIT_FAILURE);
         }
 	/* Skip until next '/' */
 	while (*idxname && *idxname != '/' && !(win32 && *idxname == '\\')) {
@@ -188,15 +179,12 @@ add_cgivar(struct cgivar *ptr, const char *name, char *value)
     tmp->name = malloc(strlen(name) + 1);
     if (tmp->name == NULL) {
 	 printf("add_cgivar_malloc");
-         free(tmp);
 	 return NULL;
     }
 
     tmp->value = malloc(strlen(value) + 1);
     if (tmp->value == NULL) {
 	 printf("add_cgivar_malloc");
-         free(tmp->name);
-         free(tmp);
 	 return NULL;
     }
 
@@ -230,21 +218,26 @@ get_query_string(void)
 	 */
         contlen = strlen(query_string);
         if (contlen > CGI_QUERY_MAX) {
-	    die("%s", _("Too long QUERY_STRING"));
+	    printf("%s text/html" CRLF CRLF, MSG_MIME_HEADER);
+            printf("%s\n", _("Too long QUERY_STRING"));
+            exit(EXIT_FAILURE);
         }
 	script_name = getenv("SCRIPT_NAME");
         if (script_name == NULL) {
             return NULL;
         }
+#if  defined(_WIN32)
     } else if (!(nmz_strprefixcasecmp(getenv("SERVER_SOFTWARE"), "Microsoft-"))
-            || !(nmz_strprefixcasecmp(getenv("SERVER_SOFTWARE"), "AnWeb"))
-            || !(nmz_strprefixcasecmp(getenv("SERVER_SOFTWARE"), "iPlanet-"))) {
+            || !(nmz_strprefixcasecmp(getenv("SERVER_SOFTWARE"), "AnWeb"))) {
 	query_string = "";
 	script_name = getenv("SCRIPT_NAME");
         if (script_name == NULL) {
             return NULL;
         }
     } else {
+#else
+    } else {
+#endif
 	/* Must not be reached here. */
 	assert(0);
     }
@@ -259,12 +252,9 @@ get_cgi_vars(const char *querystring)
     while (1) {
 	int len;
 	const char *tmp;
-        char *pSemicolon;
 	char name[BUFSIZE];
 	char value[BUFSIZE];
 
-        name[BUFSIZE - 1] = '\0';
-
 	tmp = strchr(querystring, '=');
 	if (tmp == NULL) {
 	    break;
@@ -280,11 +270,7 @@ get_cgi_vars(const char *querystring)
 
 	querystring++;
 	tmp = strchr(querystring, '&');
-        pSemicolon = strchr(querystring, ';');
-        if (tmp == NULL || (pSemicolon && (tmp > pSemicolon))) {
-            tmp = pSemicolon;
-        }
-        if (tmp == NULL) {
+	if (tmp == NULL) {
 	    tmp = querystring + strlen(querystring);  /* last point: '\0' */
 	}
 	len = tmp - querystring;
@@ -301,7 +287,7 @@ get_cgi_vars(const char *querystring)
 
 	if (cv == NULL) {
 	    fprintf(stderr, "an error occurred at add_cgivar.\n");
-	    exit_nmz(EXIT_FAILURE);
+	    exit(EXIT_FAILURE);
 	}
 
 	if (*querystring == '\0') {
@@ -446,9 +432,7 @@ process_cgi_var_max(char *value, struct cgiarg *ca)
 {
     int max;
 
-    if (sscanf(value, "%d", &max) != 1) {
-        return;
-    }
+    sscanf(value, "%d", &max);
 
     if (max < 0)
 	max = 0;
@@ -463,10 +447,7 @@ process_cgi_var_whence(char *value, struct cgiarg *ca)
 {
     int whence;
 
-    if (sscanf(value, "%d", &whence) != 1) {
-        return;
-    }
-
+    sscanf(value, "%d", &whence);
     if (whence < 0) {
 	whence = 0;
     }
@@ -506,7 +487,7 @@ process_cgi_var_idxname(char *value, struct cgiarg *ca)
     char *pp;
 
     for (pp = value; *pp ;) {
-	char name[BUFSIZE] = "", tmp[BUFSIZE] = "", *x;
+	char name[BUFSIZE], tmp[BUFSIZE], *x;
 
 	if ((x = (char *)strchr(pp, (int)','))) {
 	    *x = '\0';
@@ -521,10 +502,10 @@ process_cgi_var_idxname(char *value, struct cgiarg *ca)
 	validate_idxname(name);
 	remove_ending_slashes(name);
 
-	strncpy(tmp, nmz_get_defaultidx(), BUFSIZE - 1);
-	strncat(tmp, "/", BUFSIZE - strlen(tmp) - 1);
-	strncat(tmp, name, BUFSIZE - strlen(tmp) - 1);
-	tmp[BUFSIZE - 1] = '\0';
+	strncpy(tmp, nmz_get_defaultidx(), BUFSIZE);
+	strncat(tmp, "/", BUFSIZE - strlen(tmp));
+	strncat(tmp, name, BUFSIZE - strlen(tmp));
+	tmp[BUFSIZE -1] = '\0';
 	if (nmz_add_index(tmp) != SUCCESS) {
 	    nmz_warn_printf("invalid idxname: %s", name);
 	}
@@ -550,7 +531,7 @@ init_cgi(char *query, char *subquery)
 
     if (process_cgi_vars(&ca)) {
 	show_mini_usage();   /* if it is NOT CGI, show usage and exit */
-	exit_nmz(EXIT_FAILURE);
+	exit(EXIT_FAILURE);
     }
 
     if (nmz_get_idxnum() == 0) {
