@@ -2,10 +2,10 @@
  * 
  * form.c -
  * 
- * $Id: form.c,v 1.60.4.22 2007/12/05 16:59:36 opengl2772 Exp $
+ * $Id: form.c,v 1.60.4.8 2001/12/21 03:30:24 knok Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000-2007 Namazu Project All rights reserved.
+ * Copyright (C) 2000 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -26,19 +26,12 @@
  * 
  */
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
-#ifdef HAVE_SUPPORT_H
-#  include "support.h"
-#endif
-
+#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
-
-#ifdef HAVE_ERRNO_H
-#  include <errno.h>
+#ifdef HAVE_CONFIG_H
+#  include "config.h"
 #endif
 
 #ifdef HAVE_UNISTD_H
@@ -50,9 +43,9 @@
 #endif
 
 #ifdef HAVE_STRING_H
-#  include <string.h>
+#include <string.h>
 #else
-#  include <strings.h>
+#include <strings.h>
 #endif
 
 #include "namazu.h"
@@ -100,7 +93,7 @@ cmp_element(const char *s1, const char *s2)
             }
             s2++;
         }
-        if (_nmz_toupper((unsigned char)*s1) != _nmz_toupper((unsigned char)*s2)) {
+        if (toupper(*s1) != toupper(*s2)) {
             break;
         }
     }
@@ -118,65 +111,24 @@ static enum nmz_stat
 replace_query_value(const char *p, const char *query)
 {
     if (cmp_element(p, (char *)"input type=\"text\" name=\"query\"") == 0) {
-	char *converted = nmz_query_external(query);
-
+	char *converted = nmz_codeconv_external(query);
 	if (converted == NULL) {
 	    die("%s", strerror(errno));
 	}
 
         for (; *p; p++)
             fputc(*p, stdout);
+        printf(" value=\"");
+
+        html_print(converted);  /* for treating <>&" chars in the query. */
+        printf("\"");
 
-        {
-            printf(" value=\"");
-            html_print(converted);  /* for treating <>&" chars in the query. */
-            printf("\"");
-        }
 	free(converted);
         return SUCCESS;
     }
     return FAILURE;
 }
 
-char *
-nmz_query_external(const char *query)
-{
-    char *query_external;
-    char *alloc;
-    char *pos, *p;
-
-    alloc = strdup(query);
-    if (alloc == NULL) { /* */
-        nmz_set_dyingmsg(nmz_msg("%s", strerror(errno)));
-        return NULL;
-    }
-
-    nmz_codeconv_internal(alloc);
-
-    p = alloc;
-    while(*p == '\t') {
-        p++;
-    }
-    pos = p;
-
-    /* tr/\x01-\x1f\x7f/ /; # Remove control char. */
-    while(*p != '\0') {
-        if ((*p >= 0x01 && *p <= 0x1f) || *p == 0x7f) {
-            *p = ' ';
-        }
-        p++;
-    }
-
-    query_external = nmz_codeconv_external(pos);
-    free(alloc);
-    if (query_external == NULL) {
-        nmz_set_dyingmsg(nmz_msg("%s", strerror(errno)));
-        return NULL;
-    }
-
-    return query_external;
-}
-
 /*
  * Delete string (case insensitive)
  */
@@ -216,6 +168,7 @@ get_value(const char *s, char *value)
 static void 
 get_select_name(const char *s, char *value)
 {
+    *value = '\0';
     for (; *s; s++) {
         if (cmp_element(s, (char *)"select name=\"") == 0) {
             s = (char *)strchr(s, '"') + 1;
@@ -224,9 +177,6 @@ get_select_name(const char *s, char *value)
             }
             *value = '\0';
             return;
-        } else if (cmp_element(s, (char *)"/select") == 0) {
-            *value = '\0';
-            return;
         }
     }
 }
@@ -234,10 +184,10 @@ get_select_name(const char *s, char *value)
 static enum nmz_stat
 select_option(char *s, const char *name, const char *subquery)
 {
-    char value[BUFSIZE] = "";
+    char value[BUFSIZE];
 
     if (cmp_element(s, (char *)"option") == 0) {
-	if (strcmp(nmz_getenv("QUERY_STRING"), "")) {
+	if(strcmp(nmz_getenv("QUERY_STRING"), "")) {
             delete_str(s, (char *)"selected ");
 	}
         fputs(s, stdout);
@@ -266,7 +216,7 @@ select_option(char *s, const char *name, const char *subquery)
 	    {
 		char *p;
 		int n, order = DESCENDING;
-		char field[BUFSIZE] = "";
+		char field[BUFSIZE];
 
 		p = value + strlen("field:");
 		n = strspn(p, FIELD_SAFE_CHARS);
@@ -316,20 +266,20 @@ select_option(char *s, const char *name, const char *subquery)
 static enum nmz_stat
 check_checkbox(char *str)
 {
-    char value[BUFSIZE] = "";
+    char value[BUFSIZE];
     int i;
 
     if (cmp_element(str, "input type=\"checkbox\" name=\"idxname\"") == 0) {
         char *pp;
         int db_count, searched;
 
-	if (strcmp(nmz_getenv("QUERY_STRING"), "")) {
+	if(strcmp(nmz_getenv("QUERY_STRING"), "")) {
             delete_str(str, (char *)"checked");
 	}
         fputs(str, stdout);
         get_value(str, value);
         for (pp = value, db_count = searched = 0 ; *pp ;db_count++) {
-            char name[BUFSIZE] = "", *x;
+            char name[BUFSIZE], *x;
             if ((x = (char *)strchr(pp, (int)','))) {
                 *x = '\0';
                 strncpy(name, pp, BUFSIZE - 1);
@@ -363,7 +313,7 @@ static void
 handle_tag(const char *start, const char *end, const char *query, 
                char *select_name, const char *subquery)
 {
-    char tmp[BUFSIZE] = "";
+    char tmp[BUFSIZE];
     int l;
 
     l = end - start + 1;
@@ -377,29 +327,16 @@ handle_tag(const char *start, const char *end, const char *query,
         if (check_checkbox(tmp) == SUCCESS)
             return;
         get_select_name(tmp, select_name);
-	fputs(tmp, stdout);
-    } else {
-	fprintf(stdout, "%*.*s", l, l, start);
     }
+    fputs(tmp, stdout);
 }
 
 static char *
 read_headfoot(const char *fname) 
 {
-    char *buf, *p, tmpfname[BUFSIZE] = "", suffix[BUFSIZE] = "";
+    char *buf, *p, tmpfname[BUFSIZE], suffix[BUFSIZE];
     char *script_name;
     char *document_name;
-    size_t bufsize, newsize;
-    int i;
-
-    struct nmz_param {
-        char *name;
-        size_t len_name;
-        char *value;
-        size_t len_value;
-    };
-    struct nmz_param nmz_param_table[2];
-
 
     if (nmz_choose_msgfile_suffix(fname, suffix) != SUCCESS) {
 	nmz_warn_printf("%s: %s", fname, strerror(errno));
@@ -438,60 +375,20 @@ read_headfoot(const char *fname)
 	    if (*s == '?') {*s = 0; break;}
     }
 
-
-    /*
-       Namazu Parameter
-         0 ... {cgi}
-         1 ... {doc}
-     */
-    nmz_param_table[0].name = "{cgi}";
-    nmz_param_table[0].len_name = strlen(nmz_param_table[0].name);
-    nmz_param_table[0].value = script_name;
-    nmz_param_table[0].len_value = strlen(nmz_param_table[0].value);
-
-    nmz_param_table[1].name = "{doc}";
-    nmz_param_table[1].len_name = strlen(nmz_param_table[1].name);
-    nmz_param_table[1].value = document_name;
-    nmz_param_table[1].len_value = strlen(nmz_param_table[1].value);
-
-    newsize = bufsize = strlen(buf) + 1;
-    for (i = 0; i < sizeof(nmz_param_table) / sizeof(struct nmz_param); i++) {
-        for (p = buf; (p = strstr(p, nmz_param_table[i].name)) != NULL; p += nmz_param_table[i].len_name) {
-            newsize += (nmz_param_table[i].len_value - nmz_param_table[i].len_name);
-        }
-    }
-
-    if (newsize > bufsize) {
-        /* Expand buf memory for replacing {cgi} and {doc} */
-        buf = (char *)realloc(buf, newsize);
-        if (buf == NULL) {
-            return NULL;
-        }
+    /* Expand buf memory for replacing {cgi} and {doc} */
+    buf = (char *)realloc(buf, strlen(buf) + strlen(script_name) + strlen(document_name) + 2);
+    if (buf == NULL) {
+        return NULL;
     }
 
     /* Replace {cgi} with a proper namazu.cgi location */
+    while ((p = strstr(buf, "{cgi}")) != NULL) {
+	subst(p, "{cgi}", script_name);
+    }
+
     /* Replace {doc} with the name of the calling document eg, using SSI */
-    p = buf;
-    while (1) {
-        char *pp = NULL;
-        int idx = 0;
-
-        for (i = 0; i < sizeof(nmz_param_table) / sizeof(struct nmz_param); i++) {
-            char *pos;
-
-            if ((pos = strstr(p, nmz_param_table[i].name)) != NULL) {
-                if (pp == NULL || pp > pos) {
-                    pp = pos;
-                    idx = i;
-                }
-            }
-        }
-        if (pp == NULL) {
-            break;
-        }
-
-        subst(pp, nmz_param_table[idx].name, nmz_param_table[idx].value);
-        p = pp + nmz_param_table[idx].len_value;
+    while ((p = strstr(buf, "{doc}")) != NULL) {
+	subst(p, "{doc}", document_name);
     }
 
     return buf;
@@ -545,13 +442,11 @@ print_headfoot(const char * fname, const char * query, const char *subquery)
         if (f == 0 && *p == '<') {
             if (nmz_strprefixcasecmp(p, "</title>") == 0) {
 		if (*query != '\0') {
-		    char *converted = nmz_query_external(query);
-                    if (converted) {
-                        printf(": &lt;");
-                        html_print(converted);
-                        printf("&gt;");
-                        free(converted);
-                    }
+		    char *converted = nmz_codeconv_external(query);
+		    printf(": &lt;");
+		    html_print(converted);
+		    printf("&gt;");
+		    free(converted);
 		}
 		printf("</title>\n");
                 p = (char *)strchr(p, '>');
@@ -580,13 +475,8 @@ print_headfoot(const char * fname, const char * query, const char *subquery)
 	     */
             q = (char *)strchr(p, (int)'>');
             fputs("<", stdout);
-	    if (*(q-1) != '/') {
-		handle_tag(p + 1, q - 1, query, name, subquery);
-		fputs(">", stdout);
-	    } else {            /* for XHTML */
-		handle_tag(p + 1, q - 2, query, name, subquery);
-		fputs(" />", stdout);
-	    }
+            handle_tag(p + 1, q - 1, query, name, subquery);
+            fputs(">", stdout);
             p = q;
         } else {
             if ((strncmp(p, "\033$", 2) == 0)
@@ -604,3 +494,8 @@ print_headfoot(const char * fname, const char * query, const char *subquery)
     }
     free(buf);
 }
+
+
+
+
+
