@@ -2,7 +2,7 @@
  * 
  * namazu.c - search client of Namazu
  *
- * $Id: namazu-cmd.c,v 1.17.4.4 2004/04/01 09:45:56 opengl2772 Exp $
+ * $Id: namazu-cmd.c,v 1.17.4.2 2001/09/02 07:13:38 rug Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
  * Copyright (C) 2000 Namazu Project All rights reserved.
@@ -104,7 +104,7 @@ ck_atoi (char const *str, int *out)
 	if (*p < '0' || *p > '9')
 	    return -1;
 
-    *out = atoi (nmz_optarg);
+    *out = atoi (optarg);
     return 0;
 }
 
@@ -176,7 +176,7 @@ parse_options(int argc, char **argv)
     int opt_show_config = 0;
 
     for (;;) {
-        int ch = nmz_getopt_long(argc, argv, short_options, long_options, NULL);
+        int ch = getopt_long(argc, argv, short_options, long_options, NULL);
         if (ch == EOF) {
             break;
 	}
@@ -186,7 +186,7 @@ parse_options(int argc, char **argv)
 	    exit(EXIT_SUCCESS);
 	    break;
 	case '1':
-	    set_templatesuffix(nmz_optarg);
+	    set_templatesuffix(optarg);
 	    break;
 	case '2':
 	    nmz_set_sortmethod(SORT_BY_DATE);
@@ -198,13 +198,13 @@ parse_options(int argc, char **argv)
 	    break;
 	case '4':  /* --sort */
 	{
-	    if (strcasecmp(nmz_optarg, "score") == 0) {
+	    if (strcasecmp(optarg, "score") == 0) {
 		nmz_set_sortmethod(SORT_BY_SCORE);
-	    } else if (strcasecmp(nmz_optarg, "date") == 0) {
+	    } else if (strcasecmp(optarg, "date") == 0) {
 		nmz_set_sortmethod(SORT_BY_DATE);
-	    } else if (nmz_strprefixcasecmp(nmz_optarg, "field:") == 0) {
+	    } else if (nmz_strprefixcasecmp(optarg, "field:") == 0) {
 		nmz_set_sortmethod(SORT_BY_FIELD);
-		nmz_set_sortfield(nmz_optarg + strlen("field:"));
+		nmz_set_sortfield(optarg + strlen("field:"));
 	    }
 	}
 	break;
@@ -212,17 +212,17 @@ parse_options(int argc, char **argv)
 	    nmz_set_sortorder(ASCENDING);
 	    break;
 	case 'f':
-	    set_namazurc(nmz_optarg);
+	    set_namazurc(optarg);
 	    break;
 	case 'n':
-	    if (ck_atoi(nmz_optarg, &tmp)) {
-		die("%s: invalid argument for -n, --max", nmz_optarg);
+	    if (ck_atoi(optarg, &tmp)) {
+		die("%s: invalid argument for -n, --max", optarg);
 	    }
 	    set_maxresult(tmp);
 	    break;
 	case 'w':
-	    if (ck_atoi(nmz_optarg, &tmp)) {
-		die("%s: invalid argument for -w, --whence", nmz_optarg);
+	    if (ck_atoi(optarg, &tmp)) {
+		die("%s: invalid argument for -w, --whence", optarg);
 	    }
 	    set_listwhence(tmp);
 	    break;
@@ -272,7 +272,7 @@ parse_options(int argc, char **argv)
 	    opt_show_config = 1;
 	    break;
 	case 'o':
-	    stdio2file(nmz_optarg);
+	    stdio2file(optarg);
 	    break;
 	}
     } 
@@ -284,7 +284,7 @@ parse_options(int argc, char **argv)
 	exit(EXIT_SUCCESS);
     }
 
-    return nmz_optind;
+    return optind;
 }
 
 int 
@@ -339,7 +339,7 @@ main(int argc, char **argv)
 	    return 1;
 	}
 
-        strncpy(query, argv[i++], BUFSIZE - 1);
+        strcpy(query, argv[i++]);
         if (i < argc) {
 	    int curidx = nmz_get_idxnum();
             for (curidx = 0; i < argc && curidx < INDEX_MAX; i++) {
